@@ -34,9 +34,9 @@ namespace KCDDB
     qDebug() << "Finished";
 
     if ( job->error()==0 )
-      emit finished( Success );
+      Q_EMIT finished( Success );
     else
-      emit finished( UnknownError );
+      Q_EMIT finished( UnknownError );
   }
 }
 
